# OneDep I/O Untility Library

[![Build Status](https://dev.azure.com/wwPDB/wwPDB%20Python%20Projects/_apis/build/status/wwPDB.py-wwpdb_io?branchName=master)](https://dev.azure.com/wwPDB/wwPDB%20Python%20Projects/_build/latest?definitionId=4&branchName=master)


## Introduction
Utilities for supporting I/O operations from OneDep

### Installation

Download the library source software from the project repository:

```bash

git clone --recurse-submodules https://github.com/wwPDB/py-wwpdb_io.git

```

Optionally, run test suite using the Tox test runner

```bash
python setup.py test

or simply run

tox
```
Installation is via the program [pip](https://pypi.python.org/pypi/pip).

```bash
pip install wwpdb.io

or from the local repository:

pip install .
```
